
Received: from nf-out-0910.google.com (nf-out-0910.google.com [64.233.182.185]) by maillists.intel-research.net (8.13.8/8.13.8) with ESMTP id m6VJCsBf003863 for <dtn-users@mailman.dtnrg.org>; Thu, 31 Jul 2008 12:12:55 -0700
Received: by nf-out-0910.google.com with SMTP id e27so289318nfd.29 for <dtn-users@mailman.dtnrg.org>; Thu, 31 Jul 2008 12:12:42 -0700 (PDT)
Received: by 10.210.19.11 with SMTP id 11mr7230912ebs.93.1217531562106; Thu, 31 Jul 2008 12:12:42 -0700 (PDT)
Received: from ?192.168.1.102? ( [83.71.57.147]) by mx.google.com with ESMTPS id f8sm193084nfh.33.2008.07.31.12.12.40 (version=TLSv1/SSLv3 cipher=RC4-MD5); Thu, 31 Jul 2008 12:12:41 -0700 (PDT)
References: <300B4189-D149-47F8-BE69-8583D1AFC177@tssg.org> <b381a96a0807310658p17cf5402y788c1ac9444c9b33@mail.gmail.com> <8C39C2E3-C185-4DA7-BF7D-2545CD899646@tssg.org> <D7B522AE-362E-44E6-9C49-DBCC18D96B91@virgin.net>
Message-Id: <8E9C5783-39AA-4F8F-8701-8554589CD452@tcd.ie>
From: "Darragh O' Keeffe" <okeeffd1@tcd.ie>
To: Darren Long <darren.long@virgin.net>
In-Reply-To: <D7B522AE-362E-44E6-9C49-DBCC18D96B91@virgin.net>
Content-Type: text/plain; charset=US-ASCII; format=flowed; delsp=yes
X-Mailer: iPod Mail (4A102)
Mime-Version: 1.0 (iPod Mail 4A102)
Content-Transfer-Encoding: 7bit
Date: Thu, 31 Jul 2008 20:12:35 +0100
Cc: dtn-users mailing list <dtn-users@mailman.dtnrg.org>
Subject: Re: [dtn-users] configure (on ubuntu) question
X-BeenThere: dtn-users@maillists.intel-research.net
X-Mailman-Version: 2.1.9
Precedence: list
List-Id: dtn-users mailing list <dtn-users.maillists.intel-research.net>
List-Unsubscribe: <http://maillists.intel-research.net/mailman/listinfo/dtn-users>, <mailto:dtn-users-request@maillists.intel-research.net?subject=unsubscribe>
List-Archive: <http://maillists.intel-research.net/pipermail/dtn-users>
List-Post: <mailto:dtn-users@maillists.intel-research.net>
List-Help: <mailto:dtn-users-request@maillists.intel-research.net?subject=help>
List-Subscribe: <http://maillists.intel-research.net/mailman/listinfo/dtn-users>, <mailto:dtn-users-request@maillists.intel-research.net?subject=subscribe>
X-List-Received-Date: Thu, 31 Jul 2008 19:12:55 -0000

Yup this is exactly what I had to do as well. Only appears to be an  
issue with gcc-4.2.

Darragh

On 31 Jul 2008, at 19:18, Darren Long <darren.long@virgin.net> wrote:

> Hi all,
>
> Actually this problem seems to be related to the sue of the -Wno-long-
> double option being passed to gcc by the oasys configure script on
> Ubuntu Hardy Heron.
>
> The tweak I make to get past this is on line 3967 of the configure
> script, where I remove the "-Wno-long-double" being added to CPPFLAGS.
>
> it seems that the configure script does check that gcc supports -Wno-
> long-double but only on Mac OS X.  I assume this is related to
> compiler versions and that configure needs updating to test gcc on
> other platforms too.
>
> Darren
> On 31 Jul 2008, at 15:53, John Ronan wrote:
>
>>
>> On 31 Jul 2008, at 14:58, Alex McMahon wrote:
>>
>>> Hi John,
>>>
>>> Removing the following lines from oasys's configure worked for me.
>>>
>>>
>>> if test "${ac_cv_search_pow+set}" = set; then
>>> break
>>> fi
>>> done
>>> if test "${ac_cv_search_pow+set}" = set; then
>>> :
>>> else
>>> ac_cv_search_pow=no
>>> fi
>> Hi,
>>
>> I had to comment out a bit more but it seemed to work, thank you.
>>
>> --
>> John Ronan <jronan@tssg.org>, +353-51-302938
>> Telecommunications Software &  Systems Group,  http://www.tssg.org
>>
>>
>>
>> _______________________________________________
>> dtn-users mailing list
>> dtn-users@maillists.intel-research.net
>> http://maillists.intel-research.net/mailman/listinfo/dtn-users
>
> _______________________________________________
> dtn-users mailing list
> dtn-users@maillists.intel-research.net
> http://maillists.intel-research.net/mailman/listinfo/dtn-users
>


Received: from smtprelay-virgin.hostedemail.com (smtprelay-virgin0159.hostedemail.com [64.99.136.159]) by maillists.intel-research.net (8.13.8/8.13.8) with ESMTP id m6VIIgLh001304 for <dtn-users@mailman.dtnrg.org>; Thu, 31 Jul 2008 11:18:43 -0700
Received: from filter.hostedemail.com (ff-bigip1 [10.5.19.254]) by smtprelay08.hostedemail.com (Postfix) with SMTP id 0B8151EA6BB for <dtn-users@mailman.dtnrg.org>; Thu, 31 Jul 2008 18:18:32 +0000 (UTC)
X-SpamScore: 1
X-Spam-Summary: 20, 1.5, 0, 79c97b66d437a9ae, a97fa58bd2b5472a, darren.long@virgin.net, , RULES_HIT:355:379:541:599:601:945:960:967:968:973:980:982:988:989:1042:1260:1261:1277:1311:1313:1314:1345:1359:1437:1515:1516:1518:1534:1541:1593:1594:1711:1730:1747:1766:1792:2328:2393:2525:2553:2560:2564:2682:2685:2857:2859:2933:2937:2939:2942:2945:2947:2951:2954:3022:3027:3353:3622:3865:3866:3867:3868:3869:3871:3872:3873:3874:3934:3936:3938:3941:3944:3947:3950:3953:4184:4321:4860:5007:6119:6996:6997:7652:7679:7903:8957, 0, RBL:none, CacheIP:none, Bayesian:0.5, 0.5, 0.5, Netcheck:none, DomainCache:0, MSF:not bulk, SPF:, MSBL:none, DNSBL:none
X-session-marker: 64617272656E2E6C6F6E674076697267696E2E6E6574
Received: from [192.168.0.3] (client-86-24-115-62.nrth.adsl.virgin.net [86.24.115.62]) (Authenticated sender: darren.long@virgin.net) by omf09.hostedemail.com (Postfix) with ESMTP for <dtn-users@mailman.dtnrg.org>; Thu, 31 Jul 2008 18:18:30 +0000 (UTC)
Message-Id: <D7B522AE-362E-44E6-9C49-DBCC18D96B91@virgin.net>
From: Darren Long <darren.long@virgin.net>
To: dtn-users mailing list <dtn-users@mailman.dtnrg.org>
In-Reply-To: <8C39C2E3-C185-4DA7-BF7D-2545CD899646@tssg.org>
Content-Type: text/plain; charset=US-ASCII; format=flowed; delsp=yes
Content-Transfer-Encoding: 7bit
Mime-Version: 1.0 (Apple Message framework v928.1)
Date: Thu, 31 Jul 2008 19:18:29 +0100
References: <300B4189-D149-47F8-BE69-8583D1AFC177@tssg.org> <b381a96a0807310658p17cf5402y788c1ac9444c9b33@mail.gmail.com> <8C39C2E3-C185-4DA7-BF7D-2545CD899646@tssg.org>
X-Mailer: Apple Mail (2.928.1)
Subject: Re: [dtn-users] configure (on ubuntu) question
X-BeenThere: dtn-users@maillists.intel-research.net
X-Mailman-Version: 2.1.9
Precedence: list
List-Id: dtn-users mailing list <dtn-users.maillists.intel-research.net>
List-Unsubscribe: <http://maillists.intel-research.net/mailman/listinfo/dtn-users>, <mailto:dtn-users-request@maillists.intel-research.net?subject=unsubscribe>
List-Archive: <http://maillists.intel-research.net/pipermail/dtn-users>
List-Post: <mailto:dtn-users@maillists.intel-research.net>
List-Help: <mailto:dtn-users-request@maillists.intel-research.net?subject=help>
List-Subscribe: <http://maillists.intel-research.net/mailman/listinfo/dtn-users>, <mailto:dtn-users-request@maillists.intel-research.net?subject=subscribe>
X-List-Received-Date: Thu, 31 Jul 2008 18:18:43 -0000

Hi all,

Actually this problem seems to be related to the sue of the -Wno-long- 
double option being passed to gcc by the oasys configure script on  
Ubuntu Hardy Heron.

The tweak I make to get past this is on line 3967 of the configure  
script, where I remove the "-Wno-long-double" being added to CPPFLAGS.

it seems that the configure script does check that gcc supports -Wno- 
long-double but only on Mac OS X.  I assume this is related to  
compiler versions and that configure needs updating to test gcc on  
other platforms too.

Darren
On 31 Jul 2008, at 15:53, John Ronan wrote:

>
> On 31 Jul 2008, at 14:58, Alex McMahon wrote:
>
>> Hi John,
>>
>> Removing the following lines from oasys's configure worked for me.
>>
>>
>>  if test "${ac_cv_search_pow+set}" = set; then
>>  break
>> fi
>> done
>> if test "${ac_cv_search_pow+set}" = set; then
>>  :
>> else
>>  ac_cv_search_pow=no
>> fi
> Hi,
>
> I had to comment out a bit more but it seemed to work, thank you.
>
> --
> John Ronan <jronan@tssg.org>, +353-51-302938
> Telecommunications Software &  Systems Group,  http://www.tssg.org
>
>
>
> _______________________________________________
> dtn-users mailing list
> dtn-users@maillists.intel-research.net
> http://maillists.intel-research.net/mailman/listinfo/dtn-users



Received: from mail2.pi.elinuxservers.com (mail2.pi.elinuxservers.com [72.34.49.230]) by maillists.intel-research.net (8.13.8/8.13.8) with ESMTP id m6VErH9g024354 for <dtn-users@mailman.dtnrg.org>; Thu, 31 Jul 2008 07:53:17 -0700
Received: from [130.129.22.180] (port=60962) by pi.elinuxservers.com with esmtpsa (TLSv1:AES128-SHA:128) (Exim 4.68) (envelope-from <jronan@tssg.org>) id 1KOZWf-0001Hk-Ux for dtn-users@mailman.dtnrg.org; Thu, 31 Jul 2008 07:53:10 -0700
Mime-Version: 1.0 (Apple Message framework v753.1)
In-Reply-To: <b381a96a0807310658p17cf5402y788c1ac9444c9b33@mail.gmail.com>
References: <300B4189-D149-47F8-BE69-8583D1AFC177@tssg.org> <b381a96a0807310658p17cf5402y788c1ac9444c9b33@mail.gmail.com>
Content-Type: text/plain; charset=US-ASCII; format=flowed
Message-Id: <8C39C2E3-C185-4DA7-BF7D-2545CD899646@tssg.org>
Content-Transfer-Encoding: 7bit
From: John Ronan <jronan@tssg.org>
Date: Thu, 31 Jul 2008 15:53:07 +0100
To: dtn-users mailing list <dtn-users@mailman.dtnrg.org>
X-Mailer: Apple Mail (2.753.1)
X-AntiAbuse: This header was added to track abuse, please include it with any abuse report
X-AntiAbuse: Primary Hostname - pi.elinuxservers.com
X-AntiAbuse: Original Domain - mailman.dtnrg.org
X-AntiAbuse: Originator/Caller UID/GID - [47 12] / [47 12]
X-AntiAbuse: Sender Address Domain - tssg.org
Subject: Re: [dtn-users] configure (on ubuntu) question
X-BeenThere: dtn-users@maillists.intel-research.net
X-Mailman-Version: 2.1.9
Precedence: list
List-Id: dtn-users mailing list <dtn-users.maillists.intel-research.net>
List-Unsubscribe: <http://maillists.intel-research.net/mailman/listinfo/dtn-users>, <mailto:dtn-users-request@maillists.intel-research.net?subject=unsubscribe>
List-Archive: <http://maillists.intel-research.net/pipermail/dtn-users>
List-Post: <mailto:dtn-users@maillists.intel-research.net>
List-Help: <mailto:dtn-users-request@maillists.intel-research.net?subject=help>
List-Subscribe: <http://maillists.intel-research.net/mailman/listinfo/dtn-users>, <mailto:dtn-users-request@maillists.intel-research.net?subject=subscribe>
X-List-Received-Date: Thu, 31 Jul 2008 14:53:18 -0000

On 31 Jul 2008, at 14:58, Alex McMahon wrote:

> Hi John,
>
> Removing the following lines from oasys's configure worked for me.
>
>
>   if test "${ac_cv_search_pow+set}" = set; then
>   break
> fi
> done
> if test "${ac_cv_search_pow+set}" = set; then
>   :
> else
>   ac_cv_search_pow=no
> fi
Hi,

I had to comment out a bit more but it seemed to work, thank you.

--
John Ronan <jronan@tssg.org>, +353-51-302938
Telecommunications Software &  Systems Group,  http://www.tssg.org





Received: from rv-out-0506.google.com (rv-out-0506.google.com [209.85.198.236]) by maillists.intel-research.net (8.13.8/8.13.8) with ESMTP id m6VEILb7022768 for <dtn-users@mailman.dtnrg.org>; Thu, 31 Jul 2008 07:18:21 -0700
Received: by rv-out-0506.google.com with SMTP id b25so503354rvf.49 for <dtn-users@mailman.dtnrg.org>; Thu, 31 Jul 2008 07:18:14 -0700 (PDT)
Received: by 10.141.198.9 with SMTP id a9mr5286223rvq.238.1217513894445; Thu, 31 Jul 2008 07:18:14 -0700 (PDT)
Received: by 10.140.128.8 with HTTP; Thu, 31 Jul 2008 07:18:14 -0700 (PDT)
Message-ID: <b381a96a0807310718y607c4df8x35a3f10da7155cfa@mail.gmail.com>
Date: Thu, 31 Jul 2008 15:18:14 +0100
From: "Alex McMahon" <alexmcm@gmail.com>
To: dtn-users@mailman.dtnrg.org
MIME-Version: 1.0
Content-Type: multipart/alternative;  boundary="----=_Part_43980_4537360.1217513894444"
Subject: [dtn-users] test - don't reply
X-BeenThere: dtn-users@maillists.intel-research.net
X-Mailman-Version: 2.1.9
Precedence: list
List-Id: dtn-users mailing list <dtn-users.maillists.intel-research.net>
List-Unsubscribe: <http://maillists.intel-research.net/mailman/listinfo/dtn-users>, <mailto:dtn-users-request@maillists.intel-research.net?subject=unsubscribe>
List-Archive: <http://maillists.intel-research.net/pipermail/dtn-users>
List-Post: <mailto:dtn-users@maillists.intel-research.net>
List-Help: <mailto:dtn-users-request@maillists.intel-research.net?subject=help>
List-Subscribe: <http://maillists.intel-research.net/mailman/listinfo/dtn-users>, <mailto:dtn-users-request@maillists.intel-research.net?subject=subscribe>
X-List-Received-Date: Thu, 31 Jul 2008 14:18:21 -0000

------=_Part_43980_4537360.1217513894444
Content-Type: text/plain; charset=ISO-8859-1
Content-Transfer-Encoding: 7bit
Content-Disposition: inline



------=_Part_43980_4537360.1217513894444
Content-Type: text/html; charset=ISO-8859-1
Content-Transfer-Encoding: 7bit
Content-Disposition: inline

<div dir="ltr"><br></div>

------=_Part_43980_4537360.1217513894444--


Received: from rv-out-0506.google.com (rv-out-0506.google.com [209.85.198.235]) by maillists.intel-research.net (8.13.8/8.13.8) with ESMTP id m6VDx0gX021833 for <dtn-users@mailman.dtnrg.org>; Thu, 31 Jul 2008 06:59:00 -0700
Received: by rv-out-0506.google.com with SMTP id b25so496279rvf.49 for <dtn-users@mailman.dtnrg.org>; Thu, 31 Jul 2008 06:58:54 -0700 (PDT)
Received: by 10.140.202.12 with SMTP id z12mr5272552rvf.186.1217512734382; Thu, 31 Jul 2008 06:58:54 -0700 (PDT)
Received: by 10.140.128.8 with HTTP; Thu, 31 Jul 2008 06:58:54 -0700 (PDT)
Message-ID: <b381a96a0807310658p17cf5402y788c1ac9444c9b33@mail.gmail.com>
Date: Thu, 31 Jul 2008 14:58:54 +0100
From: "Alex McMahon" <alexmcm@gmail.com>
To: "John Ronan" <jronan@tssg.org>
In-Reply-To: <300B4189-D149-47F8-BE69-8583D1AFC177@tssg.org>
MIME-Version: 1.0
Content-Type: multipart/alternative;  boundary="----=_Part_43614_27867899.1217512734366"
References: <300B4189-D149-47F8-BE69-8583D1AFC177@tssg.org>
Cc: dtn-users mailing list <dtn-users@mailman.dtnrg.org>
Subject: Re: [dtn-users] configure (on ubuntu) question
X-BeenThere: dtn-users@maillists.intel-research.net
X-Mailman-Version: 2.1.9
Precedence: list
List-Id: dtn-users mailing list <dtn-users.maillists.intel-research.net>
List-Unsubscribe: <http://maillists.intel-research.net/mailman/listinfo/dtn-users>, <mailto:dtn-users-request@maillists.intel-research.net?subject=unsubscribe>
List-Archive: <http://maillists.intel-research.net/pipermail/dtn-users>
List-Post: <mailto:dtn-users@maillists.intel-research.net>
List-Help: <mailto:dtn-users-request@maillists.intel-research.net?subject=help>
List-Subscribe: <http://maillists.intel-research.net/mailman/listinfo/dtn-users>, <mailto:dtn-users-request@maillists.intel-research.net?subject=subscribe>
X-List-Received-Date: Thu, 31 Jul 2008 13:59:01 -0000

------=_Part_43614_27867899.1217512734366
Content-Type: text/plain; charset=ISO-8859-1
Content-Transfer-Encoding: 7bit
Content-Disposition: inline

Hi John,

Removing the following lines from oasys's configure worked for me.


  if test "${ac_cv_search_pow+set}" = set; then
  break
fi
done
if test "${ac_cv_search_pow+set}" = set; then
  :
else
  ac_cv_search_pow=no
fi


Regards

Alex McMahon

On Thu, Jul 31, 2008 at 2:34 PM, John Ronan <jronan@tssg.org> wrote:

> Hi,
>
> I'm trying to build the latest version from mercurial on ubuntu 8.04.1
>
> checking for library containing pow... no
> configure: error: can't find required library function (pow)
>
> looking at the config.log I see
> configure:6888: checking for library containing powconfigure:6929:
> gcc -o conftest   -Wno-long-double  conftest.c  >&5conftest.c:48:
> warning: conflicting types for built-in function 'pow'cc1: error:
> unrecognized command line option "-Wno-long-double"configure:6935: $?
> = 1
>
> I guess its a compiler version issue.  Given that I really don't
> understand how the autoconfigure stuff hangs together, Any ideas how
> I could fix it?
>
> Regards
> John
>
>
> --
> John Ronan <jronan@tssg.org>, +353-51-302938
> Telecommunications Software &  Systems Group,  http://www.tssg.org
>
>
>
> _______________________________________________
> dtn-users mailing list
> dtn-users@maillists.intel-research.net
> http://maillists.intel-research.net/mailman/listinfo/dtn-users
>

------=_Part_43614_27867899.1217512734366
Content-Type: text/html; charset=ISO-8859-1
Content-Transfer-Encoding: 7bit
Content-Disposition: inline

<div dir="ltr">Hi John,<br><br>Removing the following lines from oasys&#39;s configure worked for me.<br><br><br>&nbsp; if test &quot;${ac_cv_search_pow+set}&quot; = set; then<br>&nbsp; break<br>fi<br>done<br>if test &quot;${ac_cv_search_pow+set}&quot; = set; then<br>

&nbsp; :<br>else<br>&nbsp; ac_cv_search_pow=no<br>fi<br><br><br>Regards<br><br>Alex McMahon<br><br><div class="gmail_quote">On Thu, Jul 31, 2008 at 2:34 PM, John Ronan <span dir="ltr">&lt;<a href="mailto:jronan@tssg.org">jronan@tssg.org</a>&gt;</span> wrote:<br>
<blockquote class="gmail_quote" style="border-left: 1px solid rgb(204, 204, 204); margin: 0pt 0pt 0pt 0.8ex; padding-left: 1ex;">Hi,<br>
<br>
I&#39;m trying to build the latest version from mercurial on ubuntu 8.04.1<br>
<br>
checking for library containing pow... no<br>
configure: error: can&#39;t find required library function (pow)<br>
<br>
looking at the config.log I see<br>
configure:6888: checking for library containing powconfigure:6929:<br>
gcc -o conftest &nbsp; -Wno-long-double &nbsp;conftest.c &nbsp;&gt;&amp;5conftest.c:48:<br>
warning: conflicting types for built-in function &#39;pow&#39;cc1: error:<br>
unrecognized command line option &quot;-Wno-long-double&quot;configure:6935: $?<br>
= 1<br>
<br>
I guess its a compiler version issue. &nbsp;Given that I really don&#39;t<br>
understand how the autoconfigure stuff hangs together, Any ideas how<br>
I could fix it?<br>
<br>
Regards<br>
John<br>
<br>
<br>
--<br>
John Ronan &lt;<a href="mailto:jronan@tssg.org">jronan@tssg.org</a>&gt;, +353-51-302938<br>
Telecommunications Software &amp; &nbsp;Systems Group, &nbsp;<a href="http://www.tssg.org" target="_blank">http://www.tssg.org</a><br>
<br>
<br>
<br>
_______________________________________________<br>
dtn-users mailing list<br>
<a href="mailto:dtn-users@maillists.intel-research.net">dtn-users@maillists.intel-research.net</a><br>
<a href="http://maillists.intel-research.net/mailman/listinfo/dtn-users" target="_blank">http://maillists.intel-research.net/mailman/listinfo/dtn-users</a><br>
</blockquote></div><br></div>

------=_Part_43614_27867899.1217512734366--


Received: from mail2.pi.elinuxservers.com (mail2.pi.elinuxservers.com [72.34.49.230]) by maillists.intel-research.net (8.13.8/8.13.8) with ESMTP id m6VDYJbE020747 for <dtn-users@mailman.dtnrg.org>; Thu, 31 Jul 2008 06:34:19 -0700
Received: from [130.129.22.180] (port=60613) by pi.elinuxservers.com with esmtpsa (TLSv1:AES128-SHA:128) (Exim 4.68) (envelope-from <jronan@tssg.org>) id 1KOYIF-0005jt-E2 for dtn-users@mailman.dtnrg.org; Thu, 31 Jul 2008 06:34:12 -0700
Mime-Version: 1.0 (Apple Message framework v753.1)
Content-Transfer-Encoding: 7bit
Message-Id: <300B4189-D149-47F8-BE69-8583D1AFC177@tssg.org>
Content-Type: text/plain; charset=US-ASCII; delsp=yes; format=flowed
To: dtn-users mailing list <dtn-users@mailman.dtnrg.org>
From: John Ronan <jronan@tssg.org>
Date: Thu, 31 Jul 2008 14:34:03 +0100
X-Mailer: Apple Mail (2.753.1)
X-AntiAbuse: This header was added to track abuse, please include it with any abuse report
X-AntiAbuse: Primary Hostname - pi.elinuxservers.com
X-AntiAbuse: Original Domain - mailman.dtnrg.org
X-AntiAbuse: Originator/Caller UID/GID - [47 12] / [47 12]
X-AntiAbuse: Sender Address Domain - tssg.org
Subject: [dtn-users] configure (on ubuntu) question
X-BeenThere: dtn-users@maillists.intel-research.net
X-Mailman-Version: 2.1.9
Precedence: list
List-Id: dtn-users mailing list <dtn-users.maillists.intel-research.net>
List-Unsubscribe: <http://maillists.intel-research.net/mailman/listinfo/dtn-users>, <mailto:dtn-users-request@maillists.intel-research.net?subject=unsubscribe>
List-Archive: <http://maillists.intel-research.net/pipermail/dtn-users>
List-Post: <mailto:dtn-users@maillists.intel-research.net>
List-Help: <mailto:dtn-users-request@maillists.intel-research.net?subject=help>
List-Subscribe: <http://maillists.intel-research.net/mailman/listinfo/dtn-users>, <mailto:dtn-users-request@maillists.intel-research.net?subject=subscribe>
X-List-Received-Date: Thu, 31 Jul 2008 13:34:19 -0000

Hi,

I'm trying to build the latest version from mercurial on ubuntu 8.04.1

checking for library containing pow... no
configure: error: can't find required library function (pow)

looking at the config.log I see
configure:6888: checking for library containing powconfigure:6929:  
gcc -o conftest   -Wno-long-double  conftest.c  >&5conftest.c:48:  
warning: conflicting types for built-in function 'pow'cc1: error:  
unrecognized command line option "-Wno-long-double"configure:6935: $?  
= 1

I guess its a compiler version issue.  Given that I really don't  
understand how the autoconfigure stuff hangs together, Any ideas how  
I could fix it?

Regards
John


--
John Ronan <jronan@tssg.org>, +353-51-302938
Telecommunications Software &  Systems Group,  http://www.tssg.org





Received: from gateway0.EECS.Berkeley.EDU (gateway0.EECS.Berkeley.EDU [169.229.60.87]) by maillists.intel-research.net (8.13.8/8.13.7) with ESMTP id m6PHqjlP031810 for <dtn-users@mailman.dtnrg.org>; Fri, 25 Jul 2008 10:52:45 -0700
Received: from newyork.corp.kbmlabs.com (adsl-99-181-26-57.dsl.pltn13.sbcglobal.net [99.181.26.57]) (authenticated bits=0) by gateway0.EECS.Berkeley.EDU (8.14.3/8.13.5) with ESMTP id m6PIBg1J000150 (version=TLSv1/SSLv3 cipher=AES128-SHA bits=128 verify=NOT); Fri, 25 Jul 2008 11:11:44 -0700 (PDT)
From: Michael Demmer <demmer@cs.berkeley.edu>
To: Gautam Thaker <gautam.h.thaker@lmco.com>
In-Reply-To: <4889ECF4.1030303@atl.lmco.com>
References: <4880F347.5070702@atl.lmco.com> <4889ECF4.1030303@atl.lmco.com>
Message-Id: <C4CE2C53-41FB-40F8-A5B8-EB4EDDD9E29E@cs.berkeley.edu>
Content-Type: text/plain; charset=US-ASCII; format=flowed; delsp=yes
Content-Transfer-Encoding: 7bit
X-Applemailsentby: demmer
Mime-Version: 1.0 (Apple Message framework v928.1)
Date: Fri, 25 Jul 2008 11:11:37 -0700
X-Mailer: Apple Mail (2.928.1)
Cc: dtn-users@mailman.dtnrg.org
Subject: Re: [dtn-users] DTN behavior under link failure cases....
X-BeenThere: dtn-users@mailman.dtnrg.org
X-Mailman-Version: 2.1.9
Precedence: list
List-Id: dtn-users mailing list <dtn-users.mailman.dtnrg.org>
List-Unsubscribe: <http://maillists.intel-research.net/mailman/listinfo/dtn-users>, <mailto:dtn-users-request@mailman.dtnrg.org?subject=unsubscribe>
List-Archive: <http://maillists.intel-research.net/pipermail/dtn-users>
List-Post: <mailto:dtn-users@mailman.dtnrg.org>
List-Help: <mailto:dtn-users-request@mailman.dtnrg.org?subject=help>
List-Subscribe: <http://maillists.intel-research.net/mailman/listinfo/dtn-users>, <mailto:dtn-users-request@mailman.dtnrg.org?subject=subscribe>
X-List-Received-Date: Fri, 25 Jul 2008 17:52:46 -0000

If you're not using custody transfer then UDP is a bad idea since it  
won't ever retransmit if the bundle transmission gets lost.

Also you should be able to run the 'bundle list' command on either  
node to see where the bundles are. Running 'bundle info' on any one  
will show you the forwarding log and the set of bundle queues where it  
might be stuck.

In terms of the debugging output, you can selectively turn on and off  
debug targets by creating a ~/.dtndebug file containing entries like:

/dtn/cl debug
/dtn/bundle debug
+*/refs info


The + lines enable glob-like matching of the pattern rules so you can  
selectively disable things like all the refcount debugging which tends  
to overwhelm the debug noisiness.

-mike



On Jul 25, 2008, at 8:10 AM, Gautam Thaker wrote:

> In order to learn  a bit more regarding my non-working test case  
> described below, I switched to using UDP rather than
> TCP for DTN links. Further, based on a suggestion from a reader I am  
> using "min_retry_interval=1 max_retry_interval=2".
> (Yes, i wish to be reasonably aggressive in recovering once a link  
> comes back.)
>
> I further simplified the test to just 2 nodes, A->B.
>
> My link entry on node A is:
>
> link add link_udp 192.168.0.3:4556 ONDEMAND udp min_retry_interval=1  
> max_retry_interval=2
>
> The IP addresses of the link A->B ends are
>
> A(192.168.0.2) --> B(192.168.0.3)
>
> I do "ifconfig down/up" on machine A. After I bring the interface  
> back up i can "ping" in both directions (A->B and
> B->A) w/o any errors. Yet, "dtnsend" never resumes the bundle  
> transfers that were stopped by "ifconfig down". Actual
> "dtnsend" command is:
>
> dtnsend -D  -w -n 100 -z 1000 -s dtn://a.dtn/stag3 -d dtn://b.dtn/ 
> dest -t f -p /tmp/file.4
>
> Further, if I ^C the dtnsend command and merely reissue it the  
> bundle transfers resume w/o any problems.
>
> It seems to me this behavior is a bug of some type. I tried to run  
> the dtn daemons in "debug" mode, but so much output
> is produced that I can't exactly tell where things are hanging up.
>
> It seems to me that once the interface is back up and pings are  
> getting thru in both direction dtnsend and dtn daemon
> should recover.
>
> Gautam
>
>
> Gautam Thaker wrote:
>> I am trying to better understand how DTN daemons work when links  
>> are failing and coming back in some slow, periodic
>> manner. My test environment is this:
>>
>> A->B->C->D
>>
>> I am trying to send 4 byte file bundles from node A to node D.  
>> Everything work well of course when none of the 3 links
>> involved fail.
>>
>> I then run scripts on nodes A, B, and C so that their outgoing  
>> links (A's link to B, B's link to C and C's link to D)
>> go up/down using the "/sbin/ifconfig ethX up/down" command. The  
>> "down phase is 30 seconds, and the up phase is 30
>> seconds. I am using TCP links to connect the DTN daemons.
>>
>> No bundles get thru at all. Is it documented someplace as to just  
>> how things should behave in a test such as this?
>> Namely, what might be the minimum "up cycle" length for the daemon  
>> to be able to successfully hand the bundle to the
>> next person downstream? (I realize that if the up/down cycle  
>> happens too rapidly bundles may not get thru, but 30
>> seconds of up time should be enough to keep things moving.)
>>
>> Gautam
>> _______________________________________________
>> dtn-users mailing list
>> dtn-users@mailman.dtnrg.org
>> http://maillists.intel-research.net/mailman/listinfo/dtn-users
>
> _______________________________________________
> dtn-users mailing list
> dtn-users@mailman.dtnrg.org
> http://maillists.intel-research.net/mailman/listinfo/dtn-users



Received: from mailgw1a.lmco.com (mailgw1a.lmco.com [192.31.106.7]) by maillists.intel-research.net (8.13.8/8.13.7) with ESMTP id m6PEpmEB021039 for <dtn-users@mailman.dtnrg.org>; Fri, 25 Jul 2008 07:51:48 -0700
Received: from emss07g01.ems.lmco.com (relay5.ems.lmco.com [166.29.2.16])by mailgw1a.lmco.com (LM-6) with ESMTP id m6PFAnk6025162for <dtn-users@mailman.dtnrg.org>; Fri, 25 Jul 2008 09:10:49 -0600 (MDT)
Received: from CONVERSION2-DAEMON.lmco.com by lmco.com (PMDF V6.3-x14 #31428) id <0K4K00G01I61HU@lmco.com> for dtn-users@mailman.dtnrg.org; Fri, 25 Jul 2008 09:10:49 -0600 (MDT)
Received: from enterprise.atl.lmco.com ([166.17.240.20]) by lmco.com (PMDF V6.3-x14 #31428) with ESMTP id <0K4K008JOI5WK7@lmco.com> for dtn-users@mailman.dtnrg.org; Fri, 25 Jul 2008 09:10:44 -0600 (MDT)
Received: from lakehurst.atl.lmco.com (lakehurst [166.17.242.62])	by enterprise.atl.lmco.com (Postfix) with ESMTP id 4EDB5B6C6; Fri, 25 Jul 2008 11:10:44 -0400 (EDT)
Date: Fri, 25 Jul 2008 11:10:44 -0400
From: Gautam Thaker <gautam.h.thaker@lmco.com>
In-reply-to: <4880F347.5070702@atl.lmco.com>
To: dtn-users@mailman.dtnrg.org
Message-id: <4889ECF4.1030303@atl.lmco.com>
Organization: Lockheed Martin -- Advanced Technology Laboratories
MIME-version: 1.0
Content-type: text/plain; format=flowed; charset=ISO-8859-1
Content-transfer-encoding: 7BIT
User-Agent: Thunderbird 2.0.0.12 (X11/20080213)
X-Enigmail-Version: 0.95.6
References: <4880F347.5070702@atl.lmco.com>
Subject: Re: [dtn-users] DTN behavior under link failure cases....
X-BeenThere: dtn-users@mailman.dtnrg.org
X-Mailman-Version: 2.1.9
Precedence: list
List-Id: dtn-users mailing list <dtn-users.mailman.dtnrg.org>
List-Unsubscribe: <http://maillists.intel-research.net/mailman/listinfo/dtn-users>, <mailto:dtn-users-request@mailman.dtnrg.org?subject=unsubscribe>
List-Archive: <http://maillists.intel-research.net/pipermail/dtn-users>
List-Post: <mailto:dtn-users@mailman.dtnrg.org>
List-Help: <mailto:dtn-users-request@mailman.dtnrg.org?subject=help>
List-Subscribe: <http://maillists.intel-research.net/mailman/listinfo/dtn-users>, <mailto:dtn-users-request@mailman.dtnrg.org?subject=subscribe>
X-List-Received-Date: Fri, 25 Jul 2008 14:51:49 -0000

In order to learn  a bit more regarding my non-working test case described below, I switched to using UDP rather than 
TCP for DTN links. Further, based on a suggestion from a reader I am using "min_retry_interval=1 max_retry_interval=2". 
(Yes, i wish to be reasonably aggressive in recovering once a link comes back.)

I further simplified the test to just 2 nodes, A->B.

My link entry on node A is:

link add link_udp 192.168.0.3:4556 ONDEMAND udp min_retry_interval=1 max_retry_interval=2

The IP addresses of the link A->B ends are

A(192.168.0.2) --> B(192.168.0.3)

I do "ifconfig down/up" on machine A. After I bring the interface back up i can "ping" in both directions (A->B and 
B->A) w/o any errors. Yet, "dtnsend" never resumes the bundle transfers that were stopped by "ifconfig down". Actual 
"dtnsend" command is:

dtnsend -D  -w -n 100 -z 1000 -s dtn://a.dtn/stag3 -d dtn://b.dtn/dest -t f -p /tmp/file.4

Further, if I ^C the dtnsend command and merely reissue it the bundle transfers resume w/o any problems.

It seems to me this behavior is a bug of some type. I tried to run the dtn daemons in "debug" mode, but so much output 
is produced that I can't exactly tell where things are hanging up.

It seems to me that once the interface is back up and pings are getting thru in both direction dtnsend and dtn daemon 
should recover.

Gautam


Gautam Thaker wrote:
> I am trying to better understand how DTN daemons work when links are failing and coming back in some slow, periodic 
> manner. My test environment is this:
> 
> A->B->C->D
> 
> I am trying to send 4 byte file bundles from node A to node D. Everything work well of course when none of the 3 links 
> involved fail.
> 
> I then run scripts on nodes A, B, and C so that their outgoing links (A's link to B, B's link to C and C's link to D) 
> go up/down using the "/sbin/ifconfig ethX up/down" command. The "down phase is 30 seconds, and the up phase is 30 
> seconds. I am using TCP links to connect the DTN daemons.
> 
> No bundles get thru at all. Is it documented someplace as to just how things should behave in a test such as this? 
> Namely, what might be the minimum "up cycle" length for the daemon to be able to successfully hand the bundle to the 
> next person downstream? (I realize that if the up/down cycle happens too rapidly bundles may not get thru, but 30 
> seconds of up time should be enough to keep things moving.)
> 
> Gautam
> _______________________________________________
> dtn-users mailing list
> dtn-users@mailman.dtnrg.org
> http://maillists.intel-research.net/mailman/listinfo/dtn-users



Received: from mailgw2a.lmco.com (mailgw2a.lmco.com [192.91.147.7]) by maillists.intel-research.net (8.13.8/8.13.7) with ESMTP id m6IJT7oq027935 for <dtn-users@mailman.dtnrg.org>; Fri, 18 Jul 2008 12:29:07 -0700
Received: from emss03g01.ems.lmco.com (relay3.ems.lmco.com [141.240.4.144])by mailgw2a.lmco.com (LM-6) with ESMTP id m6IJlOLs020239for <dtn-users@mailman.dtnrg.org>; Fri, 18 Jul 2008 15:47:24 -0400 (EDT)
Received: from CONVERSION2-DAEMON.lmco.com by lmco.com (PMDF V6.3-x14 #31428) id <0K4700301WB05E@lmco.com> for dtn-users@mailman.dtnrg.org; Fri, 18 Jul 2008 15:47:24 -0400 (EDT)
Received: from enterprise.atl.lmco.com ([166.17.240.20]) by lmco.com (PMDF V6.3-x14 #31428) with ESMTP id <0K470017CWAVXS@lmco.com> for dtn-users@mailman.dtnrg.org; Fri, 18 Jul 2008 15:47:19 -0400 (EDT)
Received: from lakehurst.atl.lmco.com (lakehurst [166.17.242.62])	by enterprise.atl.lmco.com (Postfix) with ESMTP id 872A2B685	for <dtn-users@mailman.dtnrg.org>; Fri, 18 Jul 2008 15:47:19 -0400 (EDT)
Date: Fri, 18 Jul 2008 15:47:19 -0400
From: Gautam Thaker <gautam.h.thaker@lmco.com>
To: dtn-users@mailman.dtnrg.org
Message-id: <4880F347.5070702@atl.lmco.com>
Organization: Lockheed Martin -- Advanced Technology Laboratories
MIME-version: 1.0
Content-type: text/plain; format=flowed; charset=ISO-8859-1
Content-transfer-encoding: 7BIT
User-Agent: Thunderbird 2.0.0.12 (X11/20080213)
X-Enigmail-Version: 0.95.6
Subject: [dtn-users] DTN behavior under link failure cases....
X-BeenThere: dtn-users@mailman.dtnrg.org
X-Mailman-Version: 2.1.9
Precedence: list
List-Id: dtn-users mailing list <dtn-users.mailman.dtnrg.org>
List-Unsubscribe: <http://maillists.intel-research.net/mailman/listinfo/dtn-users>, <mailto:dtn-users-request@mailman.dtnrg.org?subject=unsubscribe>
List-Archive: <http://maillists.intel-research.net/pipermail/dtn-users>
List-Post: <mailto:dtn-users@mailman.dtnrg.org>
List-Help: <mailto:dtn-users-request@mailman.dtnrg.org?subject=help>
List-Subscribe: <http://maillists.intel-research.net/mailman/listinfo/dtn-users>, <mailto:dtn-users-request@mailman.dtnrg.org?subject=subscribe>
X-List-Received-Date: Fri, 18 Jul 2008 19:29:08 -0000

I am trying to better understand how DTN daemons work when links are failing and coming back in some slow, periodic 
manner. My test environment is this:

A->B->C->D

I am trying to send 4 byte file bundles from node A to node D. Everything work well of course when none of the 3 links 
involved fail.

I then run scripts on nodes A, B, and C so that their outgoing links (A's link to B, B's link to C and C's link to D) 
go up/down using the "/sbin/ifconfig ethX up/down" command. The "down phase is 30 seconds, and the up phase is 30 
seconds. I am using TCP links to connect the DTN daemons.

No bundles get thru at all. Is it documented someplace as to just how things should behave in a test such as this? 
Namely, what might be the minimum "up cycle" length for the daemon to be able to successfully hand the bundle to the 
next person downstream? (I realize that if the up/down cycle happens too rapidly bundles may not get thru, but 30 
seconds of up time should be enough to keep things moving.)

Gautam

